@@ -2,6 +2,7 @@ from .libs.account import AccountClient
 from .libs.actions import ActionsClient
 from .libs.articles import ArticlesRequest
 from .libs.attributes import AttributeRequest
+from .libs.artifacts import ArtifactsRequest
 from .libs.cards import CardsRequest
 from .libs.cookies import CookiesRequest
 from .libs.dns import DnsRequest
@@ -13,3 +14,4 @@ from .libs.services import ServicesRequest
 from .libs.ssl import SslRequest
 from .libs.whois import WhoisRequest
 from .libs.generic import GenericRequest
+from .libs.illuminate import IlluminateRequest
